GeoCS package
=============

Submodules
----------

GeoCS.calc\_lib module
----------------------

.. automodule:: GeoCS.calc_lib
   :members:
   :undoc-members:
   :show-inheritance:

GeoCS.data\_lib module
----------------------

.. automodule:: GeoCS.data_lib
   :members:
   :undoc-members:
   :show-inheritance:

GeoCS.plot\_lib module
----------------------

.. automodule:: GeoCS.plot_lib
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: GeoCS
   :members:
   :undoc-members:
   :show-inheritance:
